==> squeaknode-0.1.176.tar.gz: squeaknode-0.1.176/squeaknode/node/process_forward_tweets_worker.py <==
# MIT License
#
# Copyright (c) 2020 Jonathan Zernik
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
import logging
import threading

from squeaknode.node.squeak_controller import SqueakController

logger = logging.getLogger(__name__)


class ProcessForwardTweetsWorker:
    def __init__(self, twitter_forwarder):
        self.twitter_forwarder = twitter_forwarder
        self.stopped = threading.Event()

    def start_running(self, squeak_controller: SqueakController):
        threading.Thread(
            target=self.forward_tweets,
            args=(squeak_controller,),
            daemon=True,
            name="process_forward_tweets_thread",
        ).start()

    def stop_running(self):
        self.stopped.set()

    def forward_tweets(self, squeak_controller: SqueakController):
        logger.info("Starting ProcessForwardTweetsWorker...")
        self.twitter_forwarder.start_processing(squeak_controller)
        self.stopped.wait()
        logger.info("Stopping ProcessForwardTweetsWorker...")
        self.twitter_forwarder.stop_processing()

==> squeaknode-0.1.190.tar.gz: squeaknode-0.1.190/squeaknode/node/process_forward_tweets_worker.py <==
# MIT License
#
# Copyright (c) 2020 Jonathan Zernik
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
import logging
import threading


logger = logging.getLogger(__name__)


class ProcessForwardTweetsWorker:
    def __init__(self, twitter_forwarder):
        self.twitter_forwarder = twitter_forwarder
        self.stopped = threading.Event()

    def start_running(self):
        threading.Thread(
            target=self.forward_tweets,
            args=(),
            daemon=True,
            name="process_forward_tweets_thread",
        ).start()

    def stop_running(self):
        self.stopped.set()

    def forward_tweets(self):
        logger.info("Starting ProcessForwardTweetsWorker...")
        self.twitter_forwarder.start_processing()
        self.stopped.wait()
        logger.info("Stopping ProcessForwardTweetsWorker...")
        self.twitter_forwarder.stop_processing()
